@@ -1,20 +1,22 @@
 #' @title Optimizer Using the Hyperband Algorithm
-#'
+
+#' @include OptimizerSuccessiveHalving.R
 #' @name mlr_optimizers_hyperband
 #' @templateVar id hyperband
 #'
 #' @description
-#' `OptimizerHyperband` class that implements hyperband optimization (HB).
-#' HB repeatedly calls SHA ([OptimizerSuccessiveHalving]) with different
-#' numbers of starting points. A larger number of starting points corresponds to
-#' a smaller budget allocated in the base stage. Each run of SHA within HB is
-#' called a bracket. HB considers `s_max + 1` brackets with `s_max =
-#' floor(log(r_max / r_min, eta)`. The most explorative bracket `s = s_max`
-#' constructs `s_max + 1` stages and allocates the minimum budget (`r_min`) in
-#' the base stage. The minimum budget is increased in each bracket by a factor
-#' of `eta` and the number of starting points is computed so that each bracket
-#' approximately spends the same budget. Use [hyperband_schedule()] to get a
-#' preview of the bracket layout.
+#' Optimizer using the Hyperband (HB) algorithm.
+#' HB runs the [Successive Halving Algorithm][OptimizerSuccessiveHalving] (SHA) with different numbers of stating configurations.
+#' The algorithm is initialized with the same parameters as Successive Halving but without `n`.
+#' Each run of Successive Halving is called a bracket and starts with a different budget `r_0`.
+#' A smaller starting budget means that more configurations can be tried out.
+#' The most explorative bracket allocated the minimum budget `r_min`.
+#' The next bracket increases the starting budget by a factor of `eta`.
+#' In each bracket, the starting budget increases further until the last bracket `s = 0` essentially performs a random search with the full budget `r_max`.
+#' The number of brackets `s_max + 1` is calculated with `s_max = log(r_min / r_max)(eta)`.
+#' Under the condition that `r_0` increases by `eta` with each bracket, `r_min` sometimes has to be adjusted slightly in order not to use more than `r_max` resources in the last bracket.
+#' The number of configurations in the base stages is calculated so that each bracket uses approximately the same amount of budget.
+#' The following table shows a full run of HB with `eta = 2`, `r_min = 1` and `r_max = 8`.
 #'
 #' | `s` |     |       |     3 |     |       |     2 |     |       |     1 |     |       |     0 |
 #' | --: | --- | ----: | ----: | --- | ----: | ----: | --- | ----: | ----: | --- | ----: | ----: |
@@ -24,40 +26,36 @@
 #' |   2 |     |     2 |     4 |     |     1 |     8 |     |       |       |     |       |       |
 #' |   3 |     |     1 |     8 |     |       |       |     |       |       |     |       |       |
 #'
-#' `s` is the bracket number, `i` is stage number, `n_i` is the number of
-#' configurations and `r_i` is the budget allocated to a single configuration.
+#' `s` is the bracket number, `i` is the stage number, `n_i` is the number of configurations and `r_i` is the budget allocated to a single configuration.
 #'
 #' The budget hyperparameter must be tagged with `"budget"` in the search space.
-#' The minimum budget (`r_min`) which is allocated in the base stage of the most
-#' explorative bracket, is set by the lower bound of the budget parameter. The
-#' upper bound defines the maximum budget (`r_max`) which which is allocated to
-#' the candidates in the last stages.
+#' The minimum budget (`r_min`) which is allocated in the base stage of the most explorative bracket, is set by the lower bound of the budget parameter.
+#' The upper bound defines the maximum budget (`r_max`) which is allocated to the candidates in the last stages.
+#'
+#' @section Resources:
+#' The [gallery](https://mlr-org.com/gallery-all-optimization.html) features a collection of case studies and demos about optimization.
+#'
+#'  * [Tune](https://mlr-org.com/gallery/series/2023-01-15-hyperband-xgboost/) the hyperparameters of XGBoost with Hyperband.
+#'  * Use data [subsampling](https://mlr-org.com/gallery/series/2023-01-16-hyperband-subsampling/) and Hyperband to optimize a support vector machine.
 #'
-#' @templateVar id hyperband
 #' @template section_dictionary_optimizers
 #'
 #' @section Parameters:
 #' \describe{
 #' \item{`eta`}{`numeric(1)`\cr
-#' With every stage, the budget is increased by a factor of `eta`
-#' and only the best `1 / eta` points are promoted to the next stage.
-#' Non-integer values are supported, but `eta` is not allowed to be less or
-#' equal 1.
-#' }
+#'   With every stage, the budget is increased by a factor of `eta` and only the best `1 / eta` points are promoted to the next stage.
+#'   Non-integer values are supported, but `eta` is not allowed to be less or equal to 1.}
 #' \item{`sampler`}{[paradox::Sampler]\cr
-#' Object defining how the samples of the parameter space should be drawn in the
-#' base stage of each bracket. The default is uniform sampling.
-#' }
+#'   Object defining how the samples of the parameter space should be drawn in the base stage of each bracket.
+#'   The default is uniform sampling.}
 #' \item{`repetitions`}{`integer(1)`\cr
-#' If `1` (default), optimization is stopped once all brackets are evaluated.
-#' Otherwise, optimization is stopped after `repetitions` runs of hyperband. The
-#' [bbotk::Terminator] might stop the optimization before all repetitions are
-#' executed.
-#' }}
+#'   If `1` (default), optimization is stopped once all brackets are evaluated.
+#'   Otherwise, optimization is stopped after `repetitions` runs of HB.
+#'   The [bbotk::Terminator] might stop the optimization before all repetitions are executed.}
+#' }
 #'
 #' @section Archive:
-#' The [bbotk::Archive] holds the following additional columns that are specific
-#' to the hyperband algorithm:
+#' The [bbotk::Archive] holds the following additional columns that are specific to HB:
 #'   * `bracket` (`integer(1)`)\cr
 #'     The bracket index. Counts down to 0.
 #'   * `stage` (`integer(1))`\cr
@@ -68,7 +66,7 @@
 #' @template section_custom_sampler
 #' @template section_progress_bars
 #' @template section_logging
-#
+#'
 #' @source
 #' `r format_bib("li_2018")`
 #'
@@ -199,3 +197,6 @@ OptimizerHyperband = R6Class("OptimizerHyperband",
     }
   )
 )
+
+#' @include aaa.R
+optimizers[["hyperband"]] = OptimizerHyperband
